pub struct ConstraintBuilder<F: Field> { /* private fields */ }Expand description
Builds constraint systems symbolically by recording operations as constraints.
Implements CircuitBuilder with ConstraintWire as the wire type. Operations like
add and mul allocate new wires and record constraints without evaluating values.
Implementations
Sourceimpl<F: Field> ConstraintBuilder<F>
impl<F: Field> ConstraintBuilder<F>
pub fn new() -> Self
pub const fn alloc_inout(&mut self) -> ConstraintWire
pub const fn alloc_precommit(&mut self) -> ConstraintWire
pub fn build(self) -> ConstraintSystemIR<F>